==> homelawnsecurity-0.0.5.1-sources.jar: net/db64/homelawnsecurity/entity/client/zombie/ZombieGravestoneRenderer.java <==
package net.db64.homelawnsecurity.entity.client.zombie;

import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.entity.client.ModModelLayers;
import net.db64.homelawnsecurity.entity.custom.zombie.ZombieGravestoneEntity;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5617;
import net.minecraft.class_927;

public class ZombieGravestoneRenderer extends class_927<ZombieGravestoneEntity, ZombieGravestoneRenderState, ZombieGravestoneModel> {
	private static final class_2960 TEXTURE = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/zombie_gravestone.png");
	private static final class_2960 TEXTURE_CRACKS = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/zombie_gravestone_cracks.png");

	public ZombieGravestoneRenderer(class_5617.class_5618 context) {
		super(context, new ZombieGravestoneModel(context.method_32167(ModModelLayers.Zombie.ZOMBIE_GRAVESTONE)), 0.5f);
		this.method_4046(
			new ZombieGravestoneCracksFeatureRenderer<>(
				this,
				new ZombieGravestoneModel(context.method_32167(ModModelLayers.Zombie.ZOMBIE_GRAVESTONE_CRACKS)),
				TEXTURE_CRACKS
			)
		);
	}

	@Override
	public class_2960 getTexture(ZombieGravestoneRenderState state) {
		return TEXTURE;
	}

	@Override
	public void render(ZombieGravestoneRenderState state, class_4587 matrixStack, class_4597 vertexConsumerProvider, int i) {
		super.method_4054(state, matrixStack, vertexConsumerProvider, i);
	}

	@Override
	public ZombieGravestoneRenderState method_55269() {
		return new ZombieGravestoneRenderState();
	}

	@Override
	public void updateRenderState(ZombieGravestoneEntity entity, ZombieGravestoneRenderState state, float f) {
		super.method_62355(entity, state, f);

		state.setupAnimationState.method_61401(entity.setupAnimationState);
		state.health = entity.method_6032();
		state.cracks = entity.hasTriggeredDegradationStage("cracks");
		state.break1 = entity.hasTriggeredDegradationStage("break1");
		state.break2 = entity.hasTriggeredDegradationStage("break2");
		state.break3 = entity.hasTriggeredDegradationStage("break3");
		state.break4 = entity.hasTriggeredDegradationStage("break4");
	}
}

==> homelawnsecurity-0.0.5.2-sources.jar: net/db64/homelawnsecurity/entity/client/zombie/ZombieGravestoneRenderer.java <==
package net.db64.homelawnsecurity.entity.client.zombie;

import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.entity.client.ModModelLayers;
import net.db64.homelawnsecurity.entity.custom.zombie.ZombieGravestoneEntity;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_5617;
import net.minecraft.class_927;

public class ZombieGravestoneRenderer extends class_927<ZombieGravestoneEntity, ZombieGravestoneRenderState, ZombieGravestoneModel> {
	private static final class_2960 TEXTURE = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/zombie_gravestone.png");
	private static final class_2960 TEXTURE_CRACKS = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/zombie_gravestone_cracks.png");

	public ZombieGravestoneRenderer(class_5617.class_5618 context) {
		super(context, new ZombieGravestoneModel(context.method_32167(ModModelLayers.Zombie.ZOMBIE_GRAVESTONE)), 0.5f);
		this.method_4046(
			new ZombieGravestoneCracksFeatureRenderer<>(
				this,
				new ZombieGravestoneModel(context.method_32167(ModModelLayers.Zombie.ZOMBIE_GRAVESTONE_CRACKS)),
				TEXTURE_CRACKS
			)
		);
	}

	@Override
	public class_2960 getTexture(ZombieGravestoneRenderState state) {
		return TEXTURE;
	}

	@Override
	public void render(
		ZombieGravestoneRenderState state,
		class_4587 matrixStack,
		class_11659 orderedRenderCommandQueue,
		class_12075 cameraRenderState
	) {
		super.method_4054(state, matrixStack, orderedRenderCommandQueue, cameraRenderState);
	}

	@Override
	public ZombieGravestoneRenderState method_55269() {
		return new ZombieGravestoneRenderState();
	}

	@Override
	public void updateRenderState(ZombieGravestoneEntity entity, ZombieGravestoneRenderState state, float f) {
		super.method_62355(entity, state, f);

		state.setupAnimationState.method_61401(entity.setupAnimationState);
		state.health = entity.method_6032();
		state.cracks = entity.hasTriggeredDegradationStage("cracks");
		state.break1 = entity.hasTriggeredDegradationStage("break1");
		state.break2 = entity.hasTriggeredDegradationStage("break2");
		state.break3 = entity.hasTriggeredDegradationStage("break3");
		state.break4 = entity.hasTriggeredDegradationStage("break4");
	}
}
